@@ -29,6 +29,7 @@ class InputText(TagBulma): # not HTAG OPTIMIZED
         self["disabled"]=self.disabled
         self["value"]= self.value
 
+    @Tag.NoRender # avoid redrawing itself
     def changeValue(self, value):
         self.value = value
         if self.onchange:
@@ -54,6 +55,7 @@ class TextArea(TagBulma):    # not HTAG OPTIMIZED
         self["disabled"]=self.disabled
         self<=self.value
 
+    @Tag.NoRender # avoid redrawing itself
     def changeValue(self, value):
         self.value = value
         if self.onchange:
@@ -74,9 +76,9 @@ class Checkbox(TagBulma):
     def update(self):
         self.clear()
         self.add(
-            Tag.label(
+            Tag.H.label(
                 [
-                    Tag.input(
+                    Tag.H.input(
                         _checked=self.value,
                         _type="checkbox",
                         _class="checkbox",
@@ -89,6 +91,7 @@ class Checkbox(TagBulma):
             )
         )
 
+    @Tag.NoRender # avoid redrawing itself
     def switch(self):
         self.value = not self.value
         if self.onchange:
@@ -97,6 +100,7 @@ class Checkbox(TagBulma):
 
 
 
+
 class Slider(TagBulma):
     tag="input"
 
@@ -111,14 +115,18 @@ class Slider(TagBulma):
         self["oninput"] = self.bind.changeValue(b"this.value")
         self.onchange = onchange
 
+    @Tag.NoRender # avoid redrawing itself
     def changeValue(self,v):
         self["value"] = v
         if self.onchange:
             self.onchange(v)
 
 if __name__=="__main__":
+
+    import logging
+    logging.basicConfig(format='[%(levelname)-5s] %(name)s: %(message)s',level=logging.DEBUG)
+
     obj=Tag.div( )
-    obj <= Input()
     obj <= InputText("hello")
     obj <= TextArea("hello")
     obj <= Checkbox(True,"Yolo")
